@@ -18,6 +18,8 @@
    +----------------------------------------------------------------------+
 */
 
+/* $Id$ */
+
 #ifndef SOLRCLIENT_H
 #define SOLRCLIENT_H
 
@@ -44,7 +46,7 @@
 #include <ext/standard/php_string.h>
 #include <ext/standard/base64.h>
 #include <ext/pcre/php_pcre.h>
-
+   
 
 #include <Zend/zend_extensions.h>
 #include <Zend/zend_exceptions.h>
@@ -214,16 +216,6 @@ PHP_METHOD(SolrDocument, getInputDocument);
 PHP_METHOD(SolrDocument, hasChildDocuments);
 PHP_METHOD(SolrDocument, getChildDocuments);
 PHP_METHOD(SolrDocument, getChildDocumentsCount);
-/* }}} */
-
-/* {{{ SolrExtractRequest methods */
-PHP_METHOD(SolrExtractRequest, __construct);
-PHP_METHOD(SolrExtractRequest, createFromFile);
-PHP_METHOD(SolrExtractRequest, createFromStream);
-PHP_METHOD(SolrExtractRequest, __destruct);
-PHP_METHOD(SolrExtractRequest, __clone);
-PHP_METHOD(SolrExtractRequest, __sleep);
-PHP_METHOD(SolrExtractRequest, __wakeup);
 
 /* }}} */
 
@@ -242,7 +234,6 @@ PHP_METHOD(SolrInputDocument, setBoost);
 PHP_METHOD(SolrInputDocument, getBoost);
 PHP_METHOD(SolrInputDocument, clear);
 PHP_METHOD(SolrInputDocument, addField);
-PHP_METHOD(SolrInputDocument, updateField);
 PHP_METHOD(SolrInputDocument, setFieldBoost);
 PHP_METHOD(SolrInputDocument, getFieldBoost);
 PHP_METHOD(SolrInputDocument, getFieldNames);
@@ -258,8 +249,6 @@ PHP_METHOD(SolrInputDocument, getChildDocuments);
 PHP_METHOD(SolrInputDocument, hasChildDocuments);
 PHP_METHOD(SolrInputDocument, getChildDocumentsCount);
 PHP_METHOD(SolrInputDocument, addChildDocuments);
-PHP_METHOD(SolrInputDocument, setVersion);
-PHP_METHOD(SolrInputDocument, getVersion);
 /* }}} */
 
 /* {{{ SolrClient methods declarations */
@@ -276,7 +265,6 @@ PHP_METHOD(SolrClient, addDocuments);
 PHP_METHOD(SolrClient, setServlet);
 PHP_METHOD(SolrClient, setResponseWriter);
 PHP_METHOD(SolrClient, request);
-PHP_METHOD(SolrClient, sendUpdateStream);
 PHP_METHOD(SolrClient, ping);
 PHP_METHOD(SolrClient, system);
 PHP_METHOD(SolrClient, threads);
@@ -627,7 +615,6 @@ int solr_curl_debug_callback(CURL *curl_handle, curl_infotype infotype, solr_cha
 PHP_SOLR_API int solr_init_options(solr_client_options_t *options TSRMLS_DC);
 PHP_SOLR_API int solr_init_handle(solr_curl_t *sch, solr_client_options_t *options TSRMLS_DC);
 PHP_SOLR_API int solr_make_request(solr_client_t *client, solr_request_type_t request_type TSRMLS_DC);
-PHP_SOLR_API int solr_make_update_stream_request(solr_client_t *client, solr_ustream_t* stream_data, solr_string_t *request_params);
 PHP_SOLR_API void solr_free_handle(solr_curl_t *sch);
 PHP_SOLR_API void solr_free_option(solr_client_options_t *options);
 
@@ -635,14 +622,12 @@ PHP_SOLR_API void solr_free_option(solr_client_options_t *options);
 
 PHP_SOLR_API void solr_extension_register_constants(int type, int module_number TSRMLS_DC);
 PHP_SOLR_API void solr_document_register_class_constants(zend_class_entry *ce TSRMLS_DC);
-PHP_SOLR_API void solr_extract_register_class_constants(zend_class_entry *ce TSRMLS_DC);
 PHP_SOLR_API void solr_client_register_class_constants(zend_class_entry *ce TSRMLS_DC);
 PHP_SOLR_API void solr_query_register_class_constants(zend_class_entry *ce TSRMLS_DC);
 PHP_SOLR_API void solr_collapse_function_register_class_constants(zend_class_entry *ce TSRMLS_DC);
 PHP_SOLR_API void solr_response_register_class_properties(zend_class_entry *ce TSRMLS_DC);
 PHP_SOLR_API void solr_response_register_class_constants(zend_class_entry *ce TSRMLS_DC);
 PHP_SOLR_API void solr_exception_register_class_properties(zend_class_entry *ce TSRMLS_DC);
-PHP_SOLR_API void solr_input_document_register_class_constants(zend_class_entry *ce TSRMLS_DC);
 
 PHP_SOLR_API void solr_set_response_object_properties(zend_class_entry *scope, zval *response_object, const solr_client_t *client, const solr_string_t *request_url, zend_bool success TSRMLS_DC);
 PHP_SOLR_API void solr_throw_exception_ex(zend_class_entry *exception_ce, long code TSRMLS_DC, const char *filename, int file_line, const char *function_name, char *format, ...);
@@ -650,24 +635,9 @@ PHP_SOLR_API void solr_throw_exception(zend_class_entry *exception_ce, char *mes
 PHP_SOLR_API void solr_throw_solr_server_exception(solr_client_t *client,const char *requestType TSRMLS_DC);
 
 /* {{{ init functions called in constructors - allocate/initialize params_t */
-PHP_SOLR_API int solr_params_obj_ctor(zval *obj TSRMLS_DC);
-PHP_SOLR_API void solr_params_obj_dtor(zval *obj);
 PHP_SOLR_API int solr_init_params(solr_params_t *solr_params, long int index);
-
-zend_object *solr_extract_create_object_handler(zend_class_entry *ce TSRMLS_CC);
 /* }}} */
 
-PHP_SOLR_API int  solr_init_ustream(zval *obj);
-PHP_SOLR_API void solr_destroy_ustream_ex(solr_ustream_t *stream);
-PHP_SOLR_API void solr_destroy_ustream_zv(zval *obj);
-PHP_SOLR_API int  solr_fetch_ustream_entry(zval *objptr, solr_ustream_t **stream_entry TSRMLS_DC);
-
-#ifdef PHP_7
-    #define solr_destroy_ustream solr_destroy_ustream_zv
-#else
-    #define solr_destroy_ustream solr_destroy_ustream_ex
-#endif
-
 /* {{{ solr_document_t based objects methods*/
 PHP_SOLR_API solr_document_t *solr_init_document(long int document_index);
 PHP_SOLR_API solr_document_t *solr_input_doc_ctor(zval *objptr);
@@ -704,7 +674,7 @@ PHP_SOLR_API void solr_destroy_param_value(solr_param_t *param, solr_param_value
 #endif
 
 /* {{{ used for SolrDocument field manipulations */
-PHP_SOLR_API int solr_document_insert_field_value_ex(solr_field_list_t *queue, const solr_char_t *field_value, double field_boost, int modifier);
+PHP_SOLR_API int solr_document_insert_field_value(solr_field_list_t *queue, const solr_char_t *field_value, double field_boost);
 PHP_SOLR_API void field_copy_constructor_ex(solr_field_list_t **original_field_queue);
 PHP_SOLR_API void field_copy_constructor_zv(zval *field_queue_zv);
 
@@ -758,7 +728,6 @@ PHP_SOLR_API void solr_normal_param_value_display_boolean(solr_param_t *solr_par
 PHP_SOLR_API void solr_normal_param_value_display_sort_type(solr_param_t *solr_param, zval *param_value);
 
 PHP_SOLR_API int solr_param_find(zval *objptr, solr_char_t *pname, int pname_length, solr_param_t **solr_param TSRMLS_DC);
-PHP_SOLR_API solr_string_t solr_params_to_string(solr_params_t * solr_params, zend_bool url_encode);
 
 PHP_SOLR_API void solr_normal_param_value_tostring(solr_param_t *solr_param, solr_string_t *buffer, zend_bool url_encode);
 PHP_SOLR_API void solr_simple_list_param_value_tostring(solr_param_t *solr_param, solr_string_t *buffer, zend_bool url_encode);
